JBoss Tools SVN: r21904 - trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/dnd.
by jbosstools-commits@lists.jboss.org
Author: yradtsevich
Date: 2010-05-05 08:27:43 -0400 (Wed, 05 May 2010)
New Revision: 21904
Modified:
trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/dnd/VpeDnD.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-6239: Implement predictable selection after DnD.
- now dropped node is selected after DnD
Modified: trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/dnd/VpeDnD.java
===================================================================
--- trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/dnd/VpeDnD.java 2010-05-05 12:21:26 UTC (rev 21903)
+++ trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/dnd/VpeDnD.java 2010-05-05 12:27:43 UTC (rev 21904)
@@ -367,14 +367,14 @@
}
private void externalDropAny(final String flavor, final String data,
- final Point range) {
+ final int offset) {
StructuredTextEditor sourceEditor = vpeController.getSourceEditor();
if (flavor == null || flavor.length() == 0
|| !(sourceEditor instanceof IDNDTextEditor)) {
return;
}
- sourceEditor.setHighlightRange(range.x, range.y, true);
+ sourceEditor.setHighlightRange(offset, 0, true);
((IDNDTextEditor) sourceEditor).runDropCommand(flavor, data);
}
@@ -461,6 +461,9 @@
dropper.drop(vpeController.getPageContext(),
sourceInnerDragInfo, sourceDropInfo);
+ // select dropped node, JBIDE-6239
+ setSelectedNode(sourceInnerDragInfo.getNode());
+
if (sourceInnerDragInfo != null) {
sourceInnerDragInfo = null;
}
@@ -472,6 +475,17 @@
}
}
+ @SuppressWarnings("restriction")
+ private void setSelectedNode(final Node node) {
+ IndexedRegion sourceNodeBounds
+ = ((IndexedRegion)node);
+
+ vpeController.getSourceEditor().getTextViewer()
+ .getTextWidget().setSelection(
+ sourceNodeBounds.getStartOffset(),
+ sourceNodeBounds.getEndOffset());
+ }
+
private void externalDrop(nsIDOMMouseEvent mouseEvent, String flavor, String data) {
vpeController.onHideTooltip();
@@ -514,7 +528,7 @@
.println(" drop! container: " + dropInfo.getContainer().getNodeName()); //$NON-NLS-1$
}
- externalDropAny(aFlavor, data, range);
+ externalDropAny(aFlavor, data, range.x);
// TypedEvent tEvent = new TypedEvent(mouseEvent);
// tEvent.data = data;
14 years, 8 months
JBoss Tools SVN: r21903 - trunk/documentation/guides/GettingStartedGuide/en-US.
by jbosstools-commits@lists.jboss.org
Author: abogachuk
Date: 2010-05-05 08:21:26 -0400 (Wed, 05 May 2010)
New Revision: 21903
Modified:
trunk/documentation/guides/GettingStartedGuide/en-US/rad_jsf_application.xml
Log:
https://jira.jboss.org/jira/browse/TOOLSDOC-62 Minor improvements in code listings. Code listings in section 5.5 has been updated.
Modified: trunk/documentation/guides/GettingStartedGuide/en-US/rad_jsf_application.xml
===================================================================
--- trunk/documentation/guides/GettingStartedGuide/en-US/rad_jsf_application.xml 2010-05-05 11:23:53 UTC (rev 21902)
+++ trunk/documentation/guides/GettingStartedGuide/en-US/rad_jsf_application.xml 2010-05-05 12:21:26 UTC (rev 21903)
@@ -447,14 +447,12 @@
<programlisting role="JAVA"><![CDATA[import javax.faces.context.FacesContext;
import javax.servlet.http.HttpSession;
import javax.faces.application.FacesMessage;
-import java.util.Locale;
import java.util.ResourceBundle;
]]></programlisting>
<para>The whole java bean should look as follows:</para>
<programlisting role="JAVA"><![CDATA[import javax.faces.context.FacesContext;
import javax.servlet.http.HttpSession;
import javax.faces.application.FacesMessage;
-import java.util.Locale;
import java.util.ResourceBundle;
public class NumberBean
14 years, 8 months
JBoss Tools SVN: r21902 - trunk/documentation/guides/GettingStartedGuide/en-US.
by jbosstools-commits@lists.jboss.org
Author: abogachuk
Date: 2010-05-05 07:23:53 -0400 (Wed, 05 May 2010)
New Revision: 21902
Modified:
trunk/documentation/guides/GettingStartedGuide/en-US/first_seam.xml
Log:
https://jira.jboss.org/jira/browse/TOOLSDOC-62 Minor improvements in code listings. Code listing in section 3.3.1 has been updated.
Modified: trunk/documentation/guides/GettingStartedGuide/en-US/first_seam.xml
===================================================================
--- trunk/documentation/guides/GettingStartedGuide/en-US/first_seam.xml 2010-05-05 08:11:37 UTC (rev 21901)
+++ trunk/documentation/guides/GettingStartedGuide/en-US/first_seam.xml 2010-05-05 11:23:53 UTC (rev 21902)
@@ -467,14 +467,14 @@
start by adding some custom login logic.</para>
<para>Open <property>Authenticator.java</property> in JBoss Developer Studio and replace the
<property>authenticate()</property> method with this code:</para>
- <programlisting><![CDATA[public boolean authenticate() {
-if (identity.getUsername().equals("admin")
-&& identity.getPassword().equals("password")) {
-identity.addRole("admin");
-return true;
-}
-else
-return true;
+ <programlisting><![CDATA[public boolean authenticate()
+{
+ if ("admin".equals(credentials.getUsername()))
+ {
+ identity.addRole("admin");
+ return true;
+ }
+ return false;
}]]></programlisting>
</section>
<section id="secure_seam_page">
14 years, 8 months
JBoss Tools SVN: r21901 - in trunk/jst/tests/org.jboss.tools.ui.bot.ext: src/org/jboss/tools/ui/bot/ext and 3 other directories.
by jbosstools-commits@lists.jboss.org
Author: lzoubek(a)redhat.com
Date: 2010-05-05 04:11:37 -0400 (Wed, 05 May 2010)
New Revision: 21901
Added:
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/ESBBean.java
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddESB.java
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddJava.java
Removed:
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddJRE.java
Modified:
trunk/jst/tests/org.jboss.tools.ui.bot.ext/resources/SWTBotTest-default.properties
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTEclipseExt.java
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTOpenExt.java
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/Annotations.java
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/TestConfigurator.java
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddServer.java
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/ClearWorkspace.java
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/PrepareViews.java
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/RequirementBase.java
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/types/IDELabel.java
Log:
SWTBotExt : add esb runtime annotations, preparing views, small fixes
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/resources/SWTBotTest-default.properties
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/resources/SWTBotTest-default.properties 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/resources/SWTBotTest-default.properties 2010-05-05 08:11:37 UTC (rev 21901)
@@ -6,3 +6,4 @@
SERVER=EAP,5.0,1.6,/data/jboss/jboss-eap-5.0/jboss-as
#<seam version>,<seam runtime home>
SEAM=2.2,/data/jboss/jboss-eap-5.0/seam
+ESB=4.7,/data/jboss/esb-4.7
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTEclipseExt.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTEclipseExt.java 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTEclipseExt.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -477,7 +477,24 @@
open.finish(wiz, IDELabel.Button.OK);
}
}
-
+ public void addESBRuntime(String name, String version, String runtimeHome ) {
+ SWTBot wiz = open.preferenceOpen(ActionItem.Preference.JBossToolsJBossESBRuntimes.LABEL);
+ wiz.button("Add").click();
+ bot.shell(IDELabel.Shell.NEW_ESB_RUNTIME).activate();
+ bot.text(0).setText(name);
+ bot.text(1).setText(runtimeHome);
+ String[] versions = bot.comboBox().items();
+ int myIndex =0;
+ for (int index=0;index<versions.length;index++) {
+ if (version.equals(versions[index])) {
+ myIndex=index;
+ break;
+ }
+ }
+ bot.comboBox().setSelection(myIndex);
+ open.finish(bot.activeShell().bot());
+ open.finish(wiz, IDELabel.Button.OK);
+ }
/**
* adds jboss server runtime only if it's not specified yet
*
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTOpenExt.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTOpenExt.java 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTOpenExt.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -62,6 +62,7 @@
viewObj.show();
return viewObj;
}
+
/**
* closes given view
*
@@ -76,8 +77,6 @@
}
}
-
-
/**
* selects given actionItem in bot's tree();
*
@@ -87,22 +86,25 @@
SWTBotTreeItem ti = null;
try {
Iterator<String> iter = item.getGroupPath().iterator();
-
+
if (iter.hasNext()) {
String next = iter.next();
- ti = bot.tree().expandNode(next);
+ ti = bot.tree().expandNode(next);
try {
while (iter.hasNext()) {
next = iter.next();
- // expanding node is failing, so try to collapse and expand it again
+ // expanding node is failing, so try to collapse and
+ // expand it again
ti.expand();
- ti = ti.expandNode(next);
+ ti = ti.expandNode(next);
}
- next = item.getName();
- ti.expandNode(next).select();
- }
- catch (WidgetNotFoundException ex) {
- log.warn("Tree item '"+next+"' was not found, trying to collapse and reexpand parent node");
+ next = item.getName();
+ ti.expandNode(next).select();
+ } catch (WidgetNotFoundException ex) {
+ log
+ .warn("Tree item '"
+ + next
+ + "' was not found, trying to collapse and reexpand parent node");
ti.collapse();
ti.expand();
ti.select();
@@ -113,9 +115,10 @@
bot.tree().select(item.getName());
}
} catch (WidgetNotFoundException ex) {
- String exStr="Item '"+ ActionItem.getItemString(item)+ "' does not exist in tree";
- if (ti!=null) {
- exStr+=", last selected item was '"+ti.getText()+"'";
+ String exStr = "Item '" + ActionItem.getItemString(item)
+ + "' does not exist in tree";
+ if (ti != null) {
+ exStr += ", last selected item was '" + ti.getText() + "'";
}
throw new WidgetNotFoundException(exStr, ex);
}
@@ -146,7 +149,7 @@
shell.activate();
bot.table().select(perspective.getName());
bot.button("OK").click();
- log.info("Perspective switched to '"+perspective.getName()+"'");
+ log.info("Perspective switched to '" + perspective.getName() + "'");
}
/**
@@ -165,7 +168,7 @@
bot.button("Next >").click();
return bot;
}
-
+
/**
* Wait for appearance shell of given name
*
@@ -218,14 +221,28 @@
SWTBotButton btn = bot.button("Cancel");
btn.click();
}
+
/**
* clicks given button on active shell and waits until shell disappears
- * @param bot
+ *
+ * @param bot
* @param finishButtonText
*/
public void finish(SWTBot bot, String finishButtonText) {
- long timeout =480*1000;
-
+ finish(bot, finishButtonText,false);
+ }
+
+ /**
+ * clicks given button on active shell and waits until shell disappears
+ *
+ * @param bot
+ * @param finishButtonText
+ * @param autoCloseShells true if you want close all possibly risen shells when closing
+ */
+ public void finish(SWTBot bot, String finishButtonText,
+ boolean autoCloseShells) {
+ long timeout = 480 * 1000;
+
SWTBotShell activeShell = bot.activeShell();
String activeShellStr = bot.activeShell().getText();
bot.button(finishButtonText).click();
@@ -234,38 +251,58 @@
log.info("Waiting until shell '" + activeShellStr + "' closes");
try {
bot.waitUntil(shellCloses(activeShell));
- log.info("OK, shell '"+activeShellStr+"' closed.");
+ log.info("OK, shell '" + activeShellStr + "' closed.");
return;
} catch (TimeoutException ex) {
- String currentShellStr = bot.activeShell().getText();
- if (!activeShellStr.equals(currentShellStr)) {
- log.error("Unexpected shell '"+currentShellStr+"': ["+SWTUtilExt.getAllBotWidgetsAsText(bot)+"] appeared, when waiting for shell to close");
- bot.activeShell().close();
- log.info("Shell '"+currentShellStr+"' closed.");
+ if (autoCloseShells) {
+ String currentShellStr = bot.activeShell().getText();
+ if (!activeShellStr.equals(currentShellStr)) {
+ log
+ .error("Unexpected shell '"
+ + currentShellStr
+ + "': ["
+ + SWTUtilExt
+ .getAllBotWidgetsAsText(bot)
+ + "] appeared, when waiting for shell to close");
+ bot.activeShell().close();
+ log.info("Shell '" + currentShellStr + "' closed, clicking finish button again.");
+ bot.button(finishButtonText).click();
+ }
}
- if (System.currentTimeMillis()-time>timeout) {
- log.error("Shell '"+activeShellStr+"' probably hanged up (480s timeout), returning, forcing to close it, expect errors");
+ if (System.currentTimeMillis() - time > timeout) {
+ log
+ .error("Shell '"
+ + activeShellStr
+ + "' probably hanged up (480s timeout), returning, forcing to close it, expect errors");
try {
bot.activeShell().close();
activeShell.close();
bot.waitUntil(shellCloses(activeShell));
- log.info("Shell '"+activeShellStr+"' was forced to close.");
+ log.info("Shell '" + activeShellStr
+ + "' was forced to close.");
return;
- }
- catch (Exception e) {
+ } catch (Exception e) {
e.printStackTrace();
}
- throw new WidgetNotFoundException("Shell '"+activeShellStr+"' did not close after timeout", ex);
+ throw new WidgetNotFoundException("Shell '"
+ + activeShellStr + "' did not close after timeout",
+ ex);
}
log.warn("Shell '" + activeShellStr + "' is still opened");
}
}
}
+
/**
* clicks 'Finish' button on active shell and waits until shell disappears
+ *
* @param bot
*/
public void finish(SWTBot bot) {
- finish(bot,"Finish");
+ finish(bot, "Finish",false);
}
+
+ public void finish(SWTBot bot, boolean autoCloseShells) {
+ finish(bot, "Finish",autoCloseShells);
+ }
}
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/Annotations.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/ESBBean.java (rev 0)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/ESBBean.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -0,0 +1,19 @@
+package org.jboss.tools.ui.bot.ext.config;
+
+public class ESBBean {
+ public String version;
+ public String esbHome;
+
+ public static ESBBean fromString(String propValue) throws Exception{
+ try {
+ String[] esbParams = propValue.split(",");
+ ESBBean bean = new ESBBean();
+ bean.esbHome=esbParams[1];
+ bean.version=esbParams[0];
+ return bean;
+ }
+ catch (Exception ex) {
+ throw new Exception("Cannot parse ESB property line",ex);
+ }
+ }
+}
Property changes on: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/ESBBean.java
___________________________________________________________________
Name: svn:mime-type
+ text/plain
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/TestConfigurator.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/TestConfigurator.java 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/TestConfigurator.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -13,6 +13,7 @@
import org.apache.log4j.Logger;
import org.jboss.tools.ui.bot.ext.Activator;
import org.jboss.tools.ui.bot.ext.SWTTestExt;
+import org.jboss.tools.ui.bot.ext.config.Annotations.ESB;
import org.jboss.tools.ui.bot.ext.config.Annotations.SWTBotTestRequires;
import org.jboss.tools.ui.bot.ext.config.Annotations.Seam;
import org.jboss.tools.ui.bot.ext.config.Annotations.Server;
@@ -27,6 +28,7 @@
public static final String SEAM = "SEAM";
public static final String JAVA_HOME_15 = "JAVA_HOME_15";
public static final String JAVA_HOME_16 = "JAVA_HOME_16";
+ public static final String ESB = "ESB";
}
public class Values {
@@ -39,6 +41,7 @@
private static Properties swtTestProperties = new Properties();
public static ServerBean server;
public static SeamBean seam;
+ public static ESBBean esb;
static {
try {
// try to load from file first
@@ -78,6 +81,7 @@
try {
server = ServerBean.fromString(getProperty(Keys.SERVER));
seam = SeamBean.fromString(getProperty(Keys.SEAM));
+ esb = ESBBean.fromString(getProperty(Keys.ESB));
} catch (Exception e) {
// TODO Auto-generated catch block
e.printStackTrace();
@@ -93,10 +97,11 @@
checkDirExists(getProperty(Keys.JAVA_HOME_16));
checkDirExists(seam.seamHome);
checkDirExists(server.runtimeHome);
+ checkDirExists(esb.esbHome);
return true;
}
catch (Exception ex) {
- log.error(ex.getMessage()+ " incorrect configuration, set your custom properties file via 'swtbot.test.properties.file' java property");
+ log.error("'"+ex.getMessage()+ "' - incorrect configuration, set your custom properties file via '"+SWTBOT_TEST_PROPERTIES_FILE+"' java property");
return false;
}
@@ -153,6 +158,15 @@
}
return RequirementBase.createAddSeam();
}
+ private static RequirementBase getESBRequirement(ESB e) {
+ if (!e.required()) {
+ return null;
+ }
+ if (!matches(esb.version, e.operator(), e.version())) {
+ return null;
+ }
+ return RequirementBase.createAddESB();
+ }
/**
* returns list of requirements if given class (Test) can run, all this is
@@ -165,6 +179,7 @@
.getAnnotation(SWTBotTestRequires.class);
// internal list
List<RequirementBase> reqs = new ArrayList<RequirementBase>();
+ reqs.add(RequirementBase.createPrepareViews());
// all not annotated classes can run
if (requies == null) {
return reqs;
@@ -183,6 +198,13 @@
}
reqs.add(req);
}
+ if (requies.esb().required()) {
+ RequirementBase req = getESBRequirement(requies.esb());
+ if (req == null) {
+ return null;
+ }
+ reqs.add(req);
+ }
if (!"".equals(requies.perspective())) {
reqs.add(RequirementBase.createSwitchPerspective(requies
.perspective()));
Added: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddESB.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddESB.java (rev 0)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddESB.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -0,0 +1,23 @@
+package org.jboss.tools.ui.bot.ext.config.requirement;
+
+import org.jboss.tools.ui.bot.ext.SWTTestExt;
+import org.jboss.tools.ui.bot.ext.config.TestConfigurator;
+
+public class AddESB extends RequirementBase {
+
+ @Override
+ public boolean checkFulfilled() {
+ return SWTTestExt.configuredState.getEsb().isConfiured;
+ }
+
+ @Override
+ public void handle() {
+ String esbName = "ESB-"+TestConfigurator.esb.version;
+ SWTTestExt.eclipse.addESBRuntime(esbName,TestConfigurator.esb.version,TestConfigurator.esb.esbHome);
+ SWTTestExt.configuredState.getEsb().isConfiured=true;
+ SWTTestExt.configuredState.getEsb().name=esbName;
+ SWTTestExt.configuredState.getEsb().version=TestConfigurator.esb.version;
+
+ }
+
+}
Property changes on: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddESB.java
___________________________________________________________________
Name: svn:mime-type
+ text/plain
Deleted: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddJRE.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddJRE.java 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddJRE.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -1,48 +0,0 @@
-package org.jboss.tools.ui.bot.ext.config.requirement;
-
-import static org.junit.Assert.fail;
-import org.jboss.tools.ui.bot.ext.SWTTestExt;
-import org.jboss.tools.ui.bot.ext.config.TestConfigurator;
-/**
- * adds JRE among Installed JRE's
- * @author lzoubek
- *
- */
-public class AddJRE extends RequirementBase {
-
- private final String version;
- /**
- * requirement for adding JRE
- * @param version to add
- */
- public AddJRE(String version) {
- this.version = version;
- }
- @Override
- public boolean checkFulfilled() {
- return SWTTestExt.configuredState.getJreList().contains(getAddedAsName());
- }
-
- @Override
- public void handle(){
- SWTTestExt.eclipse.addJavaVM(getAddedAsName(), getJavaHome());
- SWTTestExt.configuredState.getJreList().add(getAddedAsName());
- }
- public String getAddedAsName() {
- return "JRE-"+version;
- }
- private String getJavaHome() {
- if ("1.5".equals(version)) {
- return TestConfigurator.getProperty(TestConfigurator.Keys.JAVA_HOME_15);
- }
- if ("1.6".equals(version)) {
- return TestConfigurator.getProperty(TestConfigurator.Keys.JAVA_HOME_16);
- }
- failParsing();
- return null;
- }
- private void failParsing() {
- fail("Unable to add JRE runtime, unsupported verson :"+version);
- }
-
-}
Copied: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddJava.java (from rev 21883, trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddJRE.java)
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddJava.java (rev 0)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddJava.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -0,0 +1,48 @@
+package org.jboss.tools.ui.bot.ext.config.requirement;
+
+import static org.junit.Assert.fail;
+import org.jboss.tools.ui.bot.ext.SWTTestExt;
+import org.jboss.tools.ui.bot.ext.config.TestConfigurator;
+/**
+ * adds JRE among Installed JRE's
+ * @author lzoubek
+ *
+ */
+public class AddJava extends RequirementBase {
+
+ private final String version;
+ /**
+ * requirement for adding JRE
+ * @param version to add
+ */
+ public AddJava(String version) {
+ this.version = version;
+ }
+ @Override
+ public boolean checkFulfilled() {
+ return SWTTestExt.configuredState.getJreList().contains(getAddedAsName());
+ }
+
+ @Override
+ public void handle(){
+ SWTTestExt.eclipse.addJavaVM(getAddedAsName(), getJavaHome());
+ SWTTestExt.configuredState.getJreList().add(getAddedAsName());
+ }
+ public String getAddedAsName() {
+ return "JRE-"+version;
+ }
+ private String getJavaHome() {
+ if ("1.5".equals(version)) {
+ return TestConfigurator.getProperty(TestConfigurator.Keys.JAVA_HOME_15);
+ }
+ if ("1.6".equals(version)) {
+ return TestConfigurator.getProperty(TestConfigurator.Keys.JAVA_HOME_16);
+ }
+ failParsing();
+ return null;
+ }
+ private void failParsing() {
+ fail("Unable to add JRE runtime, unsupported verson :"+version);
+ }
+
+}
Property changes on: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddJava.java
___________________________________________________________________
Name: svn:mime-type
+ text/plain
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddServer.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddServer.java 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/AddServer.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -8,10 +8,12 @@
import org.jboss.tools.ui.bot.ext.gen.IServerRuntime;
import org.jboss.tools.ui.bot.ext.gen.ActionItem.Server.JBossCommunityJBossAS42;
import org.jboss.tools.ui.bot.ext.gen.ActionItem.Server.JBossCommunityJBossAS50;
+import org.jboss.tools.ui.bot.ext.gen.ActionItem.Server.JBossCommunityJBossAS60;
import org.jboss.tools.ui.bot.ext.gen.ActionItem.Server.JBossEnterpriseMiddlewareJBossEnterpriseApplicationPlatform43;
import org.jboss.tools.ui.bot.ext.gen.ActionItem.Server.JBossEnterpriseMiddlewareJBossEnterpriseApplicationPlatform50;
import org.jboss.tools.ui.bot.ext.gen.ActionItem.ServerRuntime.JBossCommunityJBoss42Runtime;
import org.jboss.tools.ui.bot.ext.gen.ActionItem.ServerRuntime.JBossCommunityJBoss50Runtime;
+import org.jboss.tools.ui.bot.ext.gen.ActionItem.ServerRuntime.JBossCommunityJBoss60Runtime;
import org.jboss.tools.ui.bot.ext.gen.ActionItem.ServerRuntime.JBossEnterpriseMiddlewareJBossEnterpriseApplicationPlatform43Runtime;
import org.jboss.tools.ui.bot.ext.gen.ActionItem.ServerRuntime.JBossEnterpriseMiddlewareJBossEnterpriseApplicationPlatform50Runtime;
/**
@@ -25,7 +27,7 @@
public AddServer() {
String javaVer = getNeededJavaVersion(TestConfigurator.server.withJavaVersion);
if (javaVer!=null) {
- AddJRE addJava = createAddJRE(javaVer);
+ AddJava addJava = createAddJRE(javaVer);
getDependsOn().add(addJava);
javaName=addJava.getAddedAsName();
}
@@ -73,6 +75,7 @@
return new ServerInfo(JBossEnterpriseMiddlewareJBossEnterpriseApplicationPlatform50Runtime.LABEL,
JBossEnterpriseMiddlewareJBossEnterpriseApplicationPlatform50.LABEL);
}
+
} else if (TestConfigurator.Values.SERVER_TYPE_JBOSSAS.equals(serverType)) {
if ("4.2".equals(version)) {
return new ServerInfo(JBossCommunityJBoss42Runtime.LABEL,JBossCommunityJBossAS42.LABEL);
@@ -80,6 +83,9 @@
if ("5.0".equals(version)) {
return new ServerInfo(JBossCommunityJBoss50Runtime.LABEL,JBossCommunityJBossAS50.LABEL);
}
+ if ("6.0".equals(version)) {
+ return new ServerInfo(JBossCommunityJBoss60Runtime.LABEL,JBossCommunityJBossAS60.LABEL);
+ }
}
failParsing();
return null;
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/ClearWorkspace.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/ClearWorkspace.java 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/ClearWorkspace.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -1,38 +1,19 @@
package org.jboss.tools.ui.bot.ext.config.requirement;
-import java.util.List;
-import java.util.Vector;
-
import org.jboss.tools.ui.bot.ext.SWTTestExt;
-import org.jboss.tools.ui.bot.ext.gen.IView;
public class ClearWorkspace extends RequirementBase {
-
+ // this requirement will always run handle();
+ private boolean once = false;
@Override
public boolean checkFulfilled() {
- try {
- return SWTTestExt.bot.shells().length==2 && SWTTestExt.bot.editors().isEmpty() && !SWTTestExt.configuredState.isWelcomeViewVisible();
- }
- catch (Exception ex) {
- log.error("Cannot determine, if all editors and shells are closed", ex);
- return false;
- }
+ return once;
}
@Override
public void handle() {
SWTTestExt.bot.closeAllShells();
SWTTestExt.bot.closeAllEditors();
- SWTTestExt.open.viewClose(new IView(){
- public List<String> getGroupPath() {
- // TODO Auto-generated method stub
- return new Vector<String>();
- }
- public String getName() {
- // TODO Auto-generated method stub
- return "Welcome";
- }});
- SWTTestExt.configuredState.setWelcomeViewVisible(false);
-
+ once = true;
}
}
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/PrepareViews.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/PrepareViews.java 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/PrepareViews.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -24,11 +24,9 @@
public void handle() {
SWTTestExt.open.viewClose(new IView(){
public List<String> getGroupPath() {
- // TODO Auto-generated method stub
return new Vector<String>();
}
public String getName() {
- // TODO Auto-generated method stub
return "Welcome";
}});
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/RequirementBase.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/RequirementBase.java 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/RequirementBase.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -115,9 +115,13 @@
RequirementBase req = new AddSeam();
return req;
}
+ public static RequirementBase createAddESB() {
+ RequirementBase req = new AddESB();
+ return req;
+ }
- public static AddJRE createAddJRE(String version) {
- AddJRE req = new AddJRE(version);
+ public static AddJava createAddJRE(String version) {
+ AddJava req = new AddJava(version);
return req;
}
@@ -138,5 +142,12 @@
req.setPriority(-1);
return req;
}
+ public static RequirementBase createPrepareViews() {
+ RequirementBase req = new PrepareViews();
+ req.setPriority(2);
+ return req;
+ }
+
+
}
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/types/IDELabel.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/types/IDELabel.java 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/types/IDELabel.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -117,7 +117,8 @@
public static final String RENAME_COMPILATION_UNIT = "Rename Compilation Unit";
public static final String RENAME_JAVA_PROJECT = "Rename Java Project";
public static final String CONFIRM_PERSPECTIVE_SWITCH = "Confirm Perspective Switch";
- public static final String NEW_SEAM_RUNTIME = "New Seam Runtime";
+ public static final String NEW_SEAM_RUNTIME = "New Seam Runtime";
+ public static final String NEW_ESB_RUNTIME = "New JBoss ESB Runtime";
}
public class EntityGroup {
14 years, 8 months
JBoss Tools SVN: r21900 - in trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config: requirement and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: lzoubek(a)redhat.com
Date: 2010-05-05 04:01:05 -0400 (Wed, 05 May 2010)
New Revision: 21900
Added:
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/PrepareViews.java
Modified:
trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/ConfiguredState.java
Log:
SWTBotExt : added prepare views requirement
Modified: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/ConfiguredState.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/ConfiguredState.java 2010-05-04 21:06:50 UTC (rev 21899)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/ConfiguredState.java 2010-05-05 08:01:05 UTC (rev 21900)
@@ -9,21 +9,23 @@
* this class represents state of running test suite. Properties of this object
* should be changed only by classed extending {@link RequirementBase} class.
*
- * @author lzoubek
+ * @author lzoubek(a)redhat.com
*
*/
public class ConfiguredState {
private List<String> jreList = new Vector<String>();
private Server server = new Server();
private Seam seam = new Seam();
- private boolean welcomeViewVisible = true;
+ private ESB esb = new ESB();
- public boolean isWelcomeViewVisible() {
- return welcomeViewVisible;
+ private boolean viewsPrepared = false;
+
+ public boolean isViewsPrepared() {
+ return viewsPrepared;
}
- public void setWelcomeViewVisible(boolean welcomeViewVisible) {
- this.welcomeViewVisible = welcomeViewVisible;
+ public void setViewsPrepared(boolean viewsPrepared) {
+ this.viewsPrepared = viewsPrepared;
}
/**
@@ -53,6 +55,15 @@
return server;
}
+ /**
+ * gets configured esb
+ *
+ * @return
+ */
+ public ESB getEsb() {
+ return esb;
+ }
+
public class Server {
/**
* is server runtime & server added?
@@ -95,4 +106,19 @@
*/
public String name = null;
}
+
+ public class ESB {
+ /**
+ * version of ESB runtime
+ */
+ public String version = null;
+ /**
+ * is configured?
+ */
+ public boolean isConfiured = false;
+ /**
+ * name of added runtime
+ */
+ public String name = null;
+ }
}
Added: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/PrepareViews.java
===================================================================
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/PrepareViews.java (rev 0)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/PrepareViews.java 2010-05-05 08:01:05 UTC (rev 21900)
@@ -0,0 +1,47 @@
+package org.jboss.tools.ui.bot.ext.config.requirement;
+
+import java.util.List;
+import java.util.Vector;
+
+import org.eclipse.swtbot.eclipse.finder.widgets.SWTBotView;
+import org.jboss.tools.ui.bot.ext.SWTTestExt;
+import org.jboss.tools.ui.bot.ext.gen.IView;
+
+/**
+ * this is a special requirement which should run only once, main aim of this is to prepare
+ * and setup views behavior (e.g. force Console View not to steal focus)
+ * @author lzoubek(a)redhat.com
+ *
+ */
+public class PrepareViews extends RequirementBase {
+
+ @Override
+ public boolean checkFulfilled() {
+ return SWTTestExt.configuredState.isViewsPrepared();
+ }
+
+ @Override
+ public void handle() {
+ SWTTestExt.open.viewClose(new IView(){
+ public List<String> getGroupPath() {
+ // TODO Auto-generated method stub
+ return new Vector<String>();
+ }
+ public String getName() {
+ // TODO Auto-generated method stub
+ return "Welcome";
+ }});
+
+ // force console view not to steal focus when something happens
+ try {
+ SWTBotView consoleView = SWTTestExt.console.show();
+ consoleView.toolbarToggleButton("Show Console When Standard Out Changes").deselect();
+ consoleView.toolbarToggleButton("Show Console When Standard Error Changes").deselect();
+ } catch (Exception ex) {
+ // do nothing since buttons must not always be available
+ }
+ SWTTestExt.configuredState.setViewsPrepared(true);
+
+ }
+
+}
Property changes on: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/requirement/PrepareViews.java
___________________________________________________________________
Name: svn:mime-type
+ text/plain
14 years, 8 months
JBoss Tools SVN: r21899 - branches/jbosstools-3.1.x/portlet/plugins/org.jboss.tools.portlet.ui/src/org/jboss/tools/portlet/ui/internal/wizard.
by jbosstools-commits@lists.jboss.org
Author: snjeza
Date: 2010-05-04 17:06:50 -0400 (Tue, 04 May 2010)
New Revision: 21899
Modified:
branches/jbosstools-3.1.x/portlet/plugins/org.jboss.tools.portlet.ui/src/org/jboss/tools/portlet/ui/internal/wizard/AddJBossPortletWizardPage.java
Log:
https://jira.jboss.org/jira/browse/JBDS-1214 EPP 5.0 Compatibility
Modified: branches/jbosstools-3.1.x/portlet/plugins/org.jboss.tools.portlet.ui/src/org/jboss/tools/portlet/ui/internal/wizard/AddJBossPortletWizardPage.java
===================================================================
--- branches/jbosstools-3.1.x/portlet/plugins/org.jboss.tools.portlet.ui/src/org/jboss/tools/portlet/ui/internal/wizard/AddJBossPortletWizardPage.java 2010-05-04 21:01:19 UTC (rev 21898)
+++ branches/jbosstools-3.1.x/portlet/plugins/org.jboss.tools.portlet.ui/src/org/jboss/tools/portlet/ui/internal/wizard/AddJBossPortletWizardPage.java 2010-05-04 21:06:50 UTC (rev 21899)
@@ -117,141 +117,148 @@
boolean isJBossPortal = PortletUIActivator.isJBossPortalRuntime(model);
model.setBooleanProperty(ADD_PORTLET, isJBossPortal);
+ boolean isGateIn = PortletUIActivator.isGateIn(model);
+ if (isGateIn) {
+ model.setBooleanProperty(ADD_JBOSS_APP, false);
+ model.setBooleanProperty(ADD_JBOSS_PORTLET, false);
+ }
+ GridData gd;
+ if (isJBossPortal) {
+ addPortlet = new Button(composite,SWT.CHECK);
+ addPortlet.setText(ADD_PORTLET_LABEL);
+ gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+ gd.horizontalSpan = 2;
+ addPortlet.setLayoutData(gd);
+ synchHelper.synchCheckbox(addPortlet, ADD_PORTLET, null);
- addPortlet = new Button(composite,SWT.CHECK);
- addPortlet.setText(ADD_PORTLET_LABEL);
- GridData gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
- gd.horizontalSpan = 2;
- addPortlet.setLayoutData(gd);
- synchHelper.synchCheckbox(addPortlet, ADD_PORTLET, null);
+ // if exists
+ Label ifExistsLabel = new Label(composite, SWT.LEFT);
+ ifExistsLabel.setText(IF_EXISTS_LABEL);
+ ifExistsLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ ifExistsCombo = new Combo(composite,SWT.READ_ONLY);
+ ifExistsCombo.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ ifExistsCombo.setItems(new String[] {"overwrite","keep"}); //$NON-NLS-1$ //$NON-NLS-2$
+ synchHelper.synchCombo(ifExistsCombo, IF_EXISTS, null);
- // if exists
- Label ifExistsLabel = new Label(composite, SWT.LEFT);
- ifExistsLabel.setText(IF_EXISTS_LABEL);
- ifExistsLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- ifExistsCombo = new Combo(composite,SWT.READ_ONLY);
- ifExistsCombo.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- ifExistsCombo.setItems(new String[] {"overwrite","keep"}); //$NON-NLS-1$ //$NON-NLS-2$
- synchHelper.synchCombo(ifExistsCombo, IF_EXISTS, null);
-
- // instance name
- Label instanceNameLabel = new Label(composite, SWT.LEFT);
- instanceNameLabel.setText(INSTANCE_NAME_LABEL);
- instanceNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- instanceNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- instanceNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(instanceNameText, INSTANCE_NAME, null);
+ // instance name
+ Label instanceNameLabel = new Label(composite, SWT.LEFT);
+ instanceNameLabel.setText(INSTANCE_NAME_LABEL);
+ instanceNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ instanceNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ instanceNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(instanceNameText, INSTANCE_NAME, null);
- // window name
- Label pageNameLabel = new Label(composite, SWT.LEFT);
- pageNameLabel.setText(PAGE_NAME_LABEL);
- pageNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- pageNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- pageNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(pageNameText, PAGE_NAME, null);
+ // window name
+ Label pageNameLabel = new Label(composite, SWT.LEFT);
+ pageNameLabel.setText(PAGE_NAME_LABEL);
+ pageNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ pageNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ pageNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(pageNameText, PAGE_NAME, null);
- // window name
- Label windowNameLabel = new Label(composite, SWT.LEFT);
- windowNameLabel.setText(WINDOW_NAME_LABEL);
- windowNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- windowNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- windowNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(windowNameText, WINDOW_NAME, null);
+ // window name
+ Label windowNameLabel = new Label(composite, SWT.LEFT);
+ windowNameLabel.setText(WINDOW_NAME_LABEL);
+ windowNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ windowNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ windowNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(windowNameText, WINDOW_NAME, null);
- // parent reference
- Label parentReferenceLabel = new Label(composite, SWT.LEFT);
- parentReferenceLabel.setText(PARENT_PORTAL_LABEL);
- parentReferenceLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- parentReferenceText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- parentReferenceText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(parentReferenceText, PARENT_PORTAL, null);
+ // parent reference
+ Label parentReferenceLabel = new Label(composite, SWT.LEFT);
+ parentReferenceLabel.setText(PARENT_PORTAL_LABEL);
+ parentReferenceLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ parentReferenceText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ parentReferenceText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(parentReferenceText, PARENT_PORTAL, null);
- // region
- Label regionLabel = new Label(composite, SWT.LEFT);
- regionLabel.setText(PAGE_REGION_LABEL);
- regionLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- regionText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- regionText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(regionText, PAGE_REGION, null);
+ // region
+ Label regionLabel = new Label(composite, SWT.LEFT);
+ regionLabel.setText(PAGE_REGION_LABEL);
+ regionLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ regionText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ regionText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(regionText, PAGE_REGION, null);
- // height
- Label heightLabel = new Label(composite, SWT.LEFT);
- heightLabel.setText(PORTLET_HEIGHT_LABEL);
- heightLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- heightText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- heightText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(heightText, PORTLET_HEIGHT, null);
+ // height
+ Label heightLabel = new Label(composite, SWT.LEFT);
+ heightLabel.setText(PORTLET_HEIGHT_LABEL);
+ heightLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ heightText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ heightText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(heightText, PORTLET_HEIGHT, null);
- // initial window state
- Label initialWindowStateLabel = new Label(composite, SWT.LEFT);
- initialWindowStateLabel.setText(INITIAL_WINDOW_STATE_LABEL);
- initialWindowStateLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- initialWindowStateCombo = new Combo(composite,SWT.READ_ONLY);
- initialWindowStateCombo.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- initialWindowStateCombo.setItems(new String[] {"maximized","minimized","normal"}); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
- synchHelper.synchCombo(initialWindowStateCombo, INITIAL_WINDOW_STATE, null);
+ // initial window state
+ Label initialWindowStateLabel = new Label(composite, SWT.LEFT);
+ initialWindowStateLabel.setText(INITIAL_WINDOW_STATE_LABEL);
+ initialWindowStateLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ initialWindowStateCombo = new Combo(composite,SWT.READ_ONLY);
+ initialWindowStateCombo.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ initialWindowStateCombo.setItems(new String[] {"maximized","minimized","normal"}); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+ synchHelper.synchCombo(initialWindowStateCombo, INITIAL_WINDOW_STATE, null);
- addPortlet.addSelectionListener(new SelectionAdapter() {
+ addPortlet.addSelectionListener(new SelectionAdapter() {
- public void widgetSelected(SelectionEvent e) {
- enableJBossProperties();
- }
- });
- enableJBossProperties();
+ public void widgetSelected(SelectionEvent e) {
+ enableJBossProperties();
+ }
+ });
+ enableJBossProperties();
- if (isJSFPortlet() || isSeamPortlet()) {
- final Button addJBossApp = new Button(composite, SWT.CHECK);
- addJBossApp.setText(ADD_JBOSS_APP_LABEL);
- gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
- gd.horizontalSpan = 2;
- addJBossApp.setLayoutData(gd);
- synchHelper.synchCheckbox(addJBossApp, ADD_JBOSS_APP, null);
+ if (isJSFPortlet() || isSeamPortlet()) {
+ final Button addJBossApp = new Button(composite, SWT.CHECK);
+ addJBossApp.setText(ADD_JBOSS_APP_LABEL);
+ gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+ gd.horizontalSpan = 2;
+ addJBossApp.setLayoutData(gd);
+ synchHelper.synchCheckbox(addJBossApp, ADD_JBOSS_APP, null);
- // JBoss Application Name
- Label jbossAppLabel = new Label(composite, SWT.LEFT);
- jbossAppLabel.setText(JBOSS_APP_LABEL);
- jbossAppLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- final Text jbossAppText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- jbossAppText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(jbossAppText, JBOSS_APP, null);
+ // JBoss Application Name
+ Label jbossAppLabel = new Label(composite, SWT.LEFT);
+ jbossAppLabel.setText(JBOSS_APP_LABEL);
+ jbossAppLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ final Text jbossAppText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ jbossAppText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(jbossAppText, JBOSS_APP, null);
- addJBossApp.addSelectionListener(new SelectionAdapter() {
+ addJBossApp.addSelectionListener(new SelectionAdapter() {
- public void widgetSelected(SelectionEvent e) {
- boolean enable = addJBossApp.getSelection();
- jbossAppText.setEnabled(enable);
+ public void widgetSelected(SelectionEvent e) {
+ boolean enable = addJBossApp.getSelection();
+ jbossAppText.setEnabled(enable);
- }
- });
+ }
+ });
- addJBossApp.setSelection(isJBossPortal);
- jbossAppText.setEnabled(addJBossApp.getSelection());
+ addJBossApp.setSelection(isJBossPortal);
+ jbossAppText.setEnabled(addJBossApp.getSelection());
- final Button addJBossPortlet = new Button(composite, SWT.CHECK);
- addJBossPortlet.setText(ADD_JBOSS_PORTLET_LABEL);
- gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
- gd.horizontalSpan = 2;
- addJBossPortlet.setLayoutData(gd);
- synchHelper.synchCheckbox(addJBossPortlet, ADD_JBOSS_PORTLET, null);
+ final Button addJBossPortlet = new Button(composite, SWT.CHECK);
+ addJBossPortlet.setText(ADD_JBOSS_PORTLET_LABEL);
+ gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+ gd.horizontalSpan = 2;
+ addJBossPortlet.setLayoutData(gd);
+ synchHelper.synchCheckbox(addJBossPortlet, ADD_JBOSS_PORTLET, null);
+ }
+ }
- final Button copyJSFTemplates = new Button(composite, SWT.CHECK);
- copyJSFTemplates.setText(COPY_JSF_TEMPLATES_LABEL);
- gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
- gd.horizontalSpan = 2;
- copyJSFTemplates.setLayoutData(gd);
- synchHelper.synchCheckbox(copyJSFTemplates, COPY_JSF_TEMPLATES, null);
+ final Button copyJSFTemplates = new Button(composite, SWT.CHECK);
+ copyJSFTemplates.setText(COPY_JSF_TEMPLATES_LABEL);
+ gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+ gd.horizontalSpan = 2;
+ copyJSFTemplates.setLayoutData(gd);
+ synchHelper.synchCheckbox(copyJSFTemplates, COPY_JSF_TEMPLATES, null);
- boolean isGateIn = PortletUIActivator.isGateIn(model);
- model.setBooleanProperty(CONFIGURE_GATEIN_PARAMETERS, isGateIn);
+ model.setBooleanProperty(CONFIGURE_GATEIN_PARAMETERS, isGateIn);
- final Button configureGateIn = new Button(composite, SWT.CHECK);
- configureGateIn.setText(CONFIGURE_GATEIN_PARAMETERS_LABEL);
- gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
- gd.horizontalSpan = 2;
- configureGateIn.setLayoutData(gd);
- synchHelper.synchCheckbox(configureGateIn, CONFIGURE_GATEIN_PARAMETERS, null);
+ final Button configureGateIn = new Button(composite, SWT.CHECK);
+ configureGateIn.setText(CONFIGURE_GATEIN_PARAMETERS_LABEL);
+ gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+ gd.horizontalSpan = 2;
+ configureGateIn.setLayoutData(gd);
+ synchHelper.synchCheckbox(configureGateIn, CONFIGURE_GATEIN_PARAMETERS, null);
- }
+
}
public boolean canFlipToNextPage() {
14 years, 8 months
JBoss Tools SVN: r21898 - trunk/portlet/plugins/org.jboss.tools.portlet.ui/src/org/jboss/tools/portlet/ui/internal/wizard.
by jbosstools-commits@lists.jboss.org
Author: snjeza
Date: 2010-05-04 17:01:19 -0400 (Tue, 04 May 2010)
New Revision: 21898
Modified:
trunk/portlet/plugins/org.jboss.tools.portlet.ui/src/org/jboss/tools/portlet/ui/internal/wizard/AddJBossPortletWizardPage.java
Log:
https://jira.jboss.org/jira/browse/JBDS-1214 EPP 5.0 Compatibility
Modified: trunk/portlet/plugins/org.jboss.tools.portlet.ui/src/org/jboss/tools/portlet/ui/internal/wizard/AddJBossPortletWizardPage.java
===================================================================
--- trunk/portlet/plugins/org.jboss.tools.portlet.ui/src/org/jboss/tools/portlet/ui/internal/wizard/AddJBossPortletWizardPage.java 2010-05-04 20:27:44 UTC (rev 21897)
+++ trunk/portlet/plugins/org.jboss.tools.portlet.ui/src/org/jboss/tools/portlet/ui/internal/wizard/AddJBossPortletWizardPage.java 2010-05-04 21:01:19 UTC (rev 21898)
@@ -117,141 +117,148 @@
boolean isJBossPortal = PortletUIActivator.isJBossPortalRuntime(model);
model.setBooleanProperty(ADD_PORTLET, isJBossPortal);
+ boolean isGateIn = PortletUIActivator.isGateIn(model);
+ if (isGateIn) {
+ model.setBooleanProperty(ADD_JBOSS_APP, false);
+ model.setBooleanProperty(ADD_JBOSS_PORTLET, false);
+ }
+ GridData gd;
+ if (isJBossPortal) {
+ addPortlet = new Button(composite,SWT.CHECK);
+ addPortlet.setText(ADD_PORTLET_LABEL);
+ gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+ gd.horizontalSpan = 2;
+ addPortlet.setLayoutData(gd);
+ synchHelper.synchCheckbox(addPortlet, ADD_PORTLET, null);
- addPortlet = new Button(composite,SWT.CHECK);
- addPortlet.setText(ADD_PORTLET_LABEL);
- GridData gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
- gd.horizontalSpan = 2;
- addPortlet.setLayoutData(gd);
- synchHelper.synchCheckbox(addPortlet, ADD_PORTLET, null);
+ // if exists
+ Label ifExistsLabel = new Label(composite, SWT.LEFT);
+ ifExistsLabel.setText(IF_EXISTS_LABEL);
+ ifExistsLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ ifExistsCombo = new Combo(composite,SWT.READ_ONLY);
+ ifExistsCombo.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ ifExistsCombo.setItems(new String[] {"overwrite","keep"}); //$NON-NLS-1$ //$NON-NLS-2$
+ synchHelper.synchCombo(ifExistsCombo, IF_EXISTS, null);
- // if exists
- Label ifExistsLabel = new Label(composite, SWT.LEFT);
- ifExistsLabel.setText(IF_EXISTS_LABEL);
- ifExistsLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- ifExistsCombo = new Combo(composite,SWT.READ_ONLY);
- ifExistsCombo.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- ifExistsCombo.setItems(new String[] {"overwrite","keep"}); //$NON-NLS-1$ //$NON-NLS-2$
- synchHelper.synchCombo(ifExistsCombo, IF_EXISTS, null);
-
- // instance name
- Label instanceNameLabel = new Label(composite, SWT.LEFT);
- instanceNameLabel.setText(INSTANCE_NAME_LABEL);
- instanceNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- instanceNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- instanceNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(instanceNameText, INSTANCE_NAME, null);
+ // instance name
+ Label instanceNameLabel = new Label(composite, SWT.LEFT);
+ instanceNameLabel.setText(INSTANCE_NAME_LABEL);
+ instanceNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ instanceNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ instanceNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(instanceNameText, INSTANCE_NAME, null);
- // window name
- Label pageNameLabel = new Label(composite, SWT.LEFT);
- pageNameLabel.setText(PAGE_NAME_LABEL);
- pageNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- pageNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- pageNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(pageNameText, PAGE_NAME, null);
+ // window name
+ Label pageNameLabel = new Label(composite, SWT.LEFT);
+ pageNameLabel.setText(PAGE_NAME_LABEL);
+ pageNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ pageNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ pageNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(pageNameText, PAGE_NAME, null);
- // window name
- Label windowNameLabel = new Label(composite, SWT.LEFT);
- windowNameLabel.setText(WINDOW_NAME_LABEL);
- windowNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- windowNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- windowNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(windowNameText, WINDOW_NAME, null);
+ // window name
+ Label windowNameLabel = new Label(composite, SWT.LEFT);
+ windowNameLabel.setText(WINDOW_NAME_LABEL);
+ windowNameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ windowNameText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ windowNameText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(windowNameText, WINDOW_NAME, null);
- // parent reference
- Label parentReferenceLabel = new Label(composite, SWT.LEFT);
- parentReferenceLabel.setText(PARENT_PORTAL_LABEL);
- parentReferenceLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- parentReferenceText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- parentReferenceText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(parentReferenceText, PARENT_PORTAL, null);
+ // parent reference
+ Label parentReferenceLabel = new Label(composite, SWT.LEFT);
+ parentReferenceLabel.setText(PARENT_PORTAL_LABEL);
+ parentReferenceLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ parentReferenceText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ parentReferenceText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(parentReferenceText, PARENT_PORTAL, null);
- // region
- Label regionLabel = new Label(composite, SWT.LEFT);
- regionLabel.setText(PAGE_REGION_LABEL);
- regionLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- regionText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- regionText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(regionText, PAGE_REGION, null);
+ // region
+ Label regionLabel = new Label(composite, SWT.LEFT);
+ regionLabel.setText(PAGE_REGION_LABEL);
+ regionLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ regionText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ regionText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(regionText, PAGE_REGION, null);
- // height
- Label heightLabel = new Label(composite, SWT.LEFT);
- heightLabel.setText(PORTLET_HEIGHT_LABEL);
- heightLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- heightText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- heightText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(heightText, PORTLET_HEIGHT, null);
+ // height
+ Label heightLabel = new Label(composite, SWT.LEFT);
+ heightLabel.setText(PORTLET_HEIGHT_LABEL);
+ heightLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ heightText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ heightText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(heightText, PORTLET_HEIGHT, null);
- // initial window state
- Label initialWindowStateLabel = new Label(composite, SWT.LEFT);
- initialWindowStateLabel.setText(INITIAL_WINDOW_STATE_LABEL);
- initialWindowStateLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- initialWindowStateCombo = new Combo(composite,SWT.READ_ONLY);
- initialWindowStateCombo.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- initialWindowStateCombo.setItems(new String[] {"maximized","minimized","normal"}); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
- synchHelper.synchCombo(initialWindowStateCombo, INITIAL_WINDOW_STATE, null);
+ // initial window state
+ Label initialWindowStateLabel = new Label(composite, SWT.LEFT);
+ initialWindowStateLabel.setText(INITIAL_WINDOW_STATE_LABEL);
+ initialWindowStateLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ initialWindowStateCombo = new Combo(composite,SWT.READ_ONLY);
+ initialWindowStateCombo.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ initialWindowStateCombo.setItems(new String[] {"maximized","minimized","normal"}); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+ synchHelper.synchCombo(initialWindowStateCombo, INITIAL_WINDOW_STATE, null);
- addPortlet.addSelectionListener(new SelectionAdapter() {
+ addPortlet.addSelectionListener(new SelectionAdapter() {
- public void widgetSelected(SelectionEvent e) {
- enableJBossProperties();
- }
- });
- enableJBossProperties();
+ public void widgetSelected(SelectionEvent e) {
+ enableJBossProperties();
+ }
+ });
+ enableJBossProperties();
- if (isJSFPortlet() || isSeamPortlet()) {
- final Button addJBossApp = new Button(composite, SWT.CHECK);
- addJBossApp.setText(ADD_JBOSS_APP_LABEL);
- gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
- gd.horizontalSpan = 2;
- addJBossApp.setLayoutData(gd);
- synchHelper.synchCheckbox(addJBossApp, ADD_JBOSS_APP, null);
+ if (isJSFPortlet() || isSeamPortlet()) {
+ final Button addJBossApp = new Button(composite, SWT.CHECK);
+ addJBossApp.setText(ADD_JBOSS_APP_LABEL);
+ gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+ gd.horizontalSpan = 2;
+ addJBossApp.setLayoutData(gd);
+ synchHelper.synchCheckbox(addJBossApp, ADD_JBOSS_APP, null);
- // JBoss Application Name
- Label jbossAppLabel = new Label(composite, SWT.LEFT);
- jbossAppLabel.setText(JBOSS_APP_LABEL);
- jbossAppLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
- final Text jbossAppText = new Text(composite, SWT.SINGLE | SWT.BORDER);
- jbossAppText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- synchHelper.synchText(jbossAppText, JBOSS_APP, null);
+ // JBoss Application Name
+ Label jbossAppLabel = new Label(composite, SWT.LEFT);
+ jbossAppLabel.setText(JBOSS_APP_LABEL);
+ jbossAppLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING));
+ final Text jbossAppText = new Text(composite, SWT.SINGLE | SWT.BORDER);
+ jbossAppText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ synchHelper.synchText(jbossAppText, JBOSS_APP, null);
- addJBossApp.addSelectionListener(new SelectionAdapter() {
+ addJBossApp.addSelectionListener(new SelectionAdapter() {
- public void widgetSelected(SelectionEvent e) {
- boolean enable = addJBossApp.getSelection();
- jbossAppText.setEnabled(enable);
+ public void widgetSelected(SelectionEvent e) {
+ boolean enable = addJBossApp.getSelection();
+ jbossAppText.setEnabled(enable);
- }
- });
+ }
+ });
- addJBossApp.setSelection(isJBossPortal);
- jbossAppText.setEnabled(addJBossApp.getSelection());
+ addJBossApp.setSelection(isJBossPortal);
+ jbossAppText.setEnabled(addJBossApp.getSelection());
- final Button addJBossPortlet = new Button(composite, SWT.CHECK);
- addJBossPortlet.setText(ADD_JBOSS_PORTLET_LABEL);
- gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
- gd.horizontalSpan = 2;
- addJBossPortlet.setLayoutData(gd);
- synchHelper.synchCheckbox(addJBossPortlet, ADD_JBOSS_PORTLET, null);
+ final Button addJBossPortlet = new Button(composite, SWT.CHECK);
+ addJBossPortlet.setText(ADD_JBOSS_PORTLET_LABEL);
+ gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+ gd.horizontalSpan = 2;
+ addJBossPortlet.setLayoutData(gd);
+ synchHelper.synchCheckbox(addJBossPortlet, ADD_JBOSS_PORTLET, null);
+ }
+ }
- final Button copyJSFTemplates = new Button(composite, SWT.CHECK);
- copyJSFTemplates.setText(COPY_JSF_TEMPLATES_LABEL);
- gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
- gd.horizontalSpan = 2;
- copyJSFTemplates.setLayoutData(gd);
- synchHelper.synchCheckbox(copyJSFTemplates, COPY_JSF_TEMPLATES, null);
+ final Button copyJSFTemplates = new Button(composite, SWT.CHECK);
+ copyJSFTemplates.setText(COPY_JSF_TEMPLATES_LABEL);
+ gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+ gd.horizontalSpan = 2;
+ copyJSFTemplates.setLayoutData(gd);
+ synchHelper.synchCheckbox(copyJSFTemplates, COPY_JSF_TEMPLATES, null);
- boolean isGateIn = PortletUIActivator.isGateIn(model);
- model.setBooleanProperty(CONFIGURE_GATEIN_PARAMETERS, isGateIn);
+ model.setBooleanProperty(CONFIGURE_GATEIN_PARAMETERS, isGateIn);
- final Button configureGateIn = new Button(composite, SWT.CHECK);
- configureGateIn.setText(CONFIGURE_GATEIN_PARAMETERS_LABEL);
- gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
- gd.horizontalSpan = 2;
- configureGateIn.setLayoutData(gd);
- synchHelper.synchCheckbox(configureGateIn, CONFIGURE_GATEIN_PARAMETERS, null);
+ final Button configureGateIn = new Button(composite, SWT.CHECK);
+ configureGateIn.setText(CONFIGURE_GATEIN_PARAMETERS_LABEL);
+ gd = new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING);
+ gd.horizontalSpan = 2;
+ configureGateIn.setLayoutData(gd);
+ synchHelper.synchCheckbox(configureGateIn, CONFIGURE_GATEIN_PARAMETERS, null);
- }
+
}
public boolean canFlipToNextPage() {
14 years, 8 months
JBoss Tools SVN: r21897 - trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/xpath.
by jbosstools-commits@lists.jboss.org
Author: bbrodt
Date: 2010-05-04 16:27:44 -0400 (Tue, 04 May 2010)
New Revision: 21897
Modified:
trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/xpath/XPathValidator.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-6015
Allow unary expressions in "if" Conditions
Modified: trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/xpath/XPathValidator.java
===================================================================
--- trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/xpath/XPathValidator.java 2010-05-04 18:21:29 UTC (rev 21896)
+++ trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/xpath/XPathValidator.java 2010-05-04 20:27:44 UTC (rev 21897)
@@ -407,6 +407,11 @@
mVisitor.visit((EqualityExpr) expr);
} else if (expr instanceof RelationalExpr) {
mVisitor.visit((RelationalExpr) expr);
+ } else if (expr instanceof UnaryExpr && !(((UnaryExpr)expr).getExpr() instanceof FunctionCallExpr)) {
+ // https://jira.jboss.org/jira/browse/JBIDE-6015
+ // Allow unary expressions like variable references and literals
+ // Since we're using XPath 1.0 there's no XSD type checking
+ mVisitor.visit((UnaryExpr) expr);
} else {
FunctionCallExpr fce = null;
// JBIDE-5999
14 years, 8 months
JBoss Tools SVN: r21896 - trunk/hibernatetools/plugins/org.hibernate.eclipse/src/org/hibernate/console.
by jbosstools-commits@lists.jboss.org
Author: vyemialyanchyk
Date: 2010-05-04 14:21:29 -0400 (Tue, 04 May 2010)
New Revision: 21896
Modified:
trunk/hibernatetools/plugins/org.hibernate.eclipse/src/org/hibernate/console/ConsoleConfiguration.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-5997 - fix in trunk
Modified: trunk/hibernatetools/plugins/org.hibernate.eclipse/src/org/hibernate/console/ConsoleConfiguration.java
===================================================================
--- trunk/hibernatetools/plugins/org.hibernate.eclipse/src/org/hibernate/console/ConsoleConfiguration.java 2010-05-04 16:59:02 UTC (rev 21895)
+++ trunk/hibernatetools/plugins/org.hibernate.eclipse/src/org/hibernate/console/ConsoleConfiguration.java 2010-05-04 18:21:29 UTC (rev 21896)
@@ -156,6 +156,8 @@
Map<Object,Object> overrides = new HashMap<Object,Object>();
if(properties!=null) {
overrides.putAll( properties );
+ } else {
+ overrides.put("hibernate.search.autoregister_listeners", "false"); //$NON-NLS-1$ //$NON-NLS-2$
}
if(StringHelper.isNotEmpty( prefs.getNamingStrategy())) {
overrides.put( "hibernate.ejb.naming_strategy", prefs.getNamingStrategy() ); //$NON-NLS-1$
@@ -746,6 +748,8 @@
private Configuration configureStandardConfiguration(final boolean includeMappings, Configuration localCfg, Properties properties) {
if(properties!=null) {
localCfg = localCfg.setProperties(properties);
+ } else {
+ localCfg.setProperty("hibernate.search.autoregister_listeners", "false"); //$NON-NLS-1$ //$NON-NLS-2$
}
EntityResolver entityResolver = XMLHelper.DEFAULT_DTD_RESOLVER;
if(StringHelper.isNotEmpty(prefs.getEntityResolverName())) {
14 years, 8 months
JBoss Tools SVN: r21895 - in trunk/seam/docs/reference/en-US: images/directory_structure and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: smukhina
Date: 2010-05-04 12:59:02 -0400 (Tue, 04 May 2010)
New Revision: 21895
Added:
trunk/seam/docs/reference/en-US/images/directory_structure/directory_structure_7.png
trunk/seam/docs/reference/en-US/images/directory_structure/directory_structure_8.png
Modified:
trunk/seam/docs/reference/en-US/directory_structure.xml
Log:
TOOLSDOC-70-Option to specify the
project(s) name in the "Seam Web project" wizard - description and images are added
Modified: trunk/seam/docs/reference/en-US/directory_structure.xml
===================================================================
--- trunk/seam/docs/reference/en-US/directory_structure.xml 2010-05-04 16:56:24 UTC (rev 21894)
+++ trunk/seam/docs/reference/en-US/directory_structure.xml 2010-05-04 16:59:02 UTC (rev 21895)
@@ -1,209 +1,230 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<chapter id="directory_str" xreflabel="directory_str">
- <?dbhtml filename="directory_structure.html"?>
- <chapterinfo>
- <keywordset>
- <keyword>JBoss Tools</keyword>
- <keyword>Seam</keyword>
- <keyword>Eclipse</keyword>
- </keywordset>
- </chapterinfo>
-
- <title>Directory Structure of the Generated Project</title>
-
- <para>In this chapter we describe where the Seam wizard puts the generated files for both EAR
- and WAR deployments.</para>
- <para>The Seam Project wizard generates projects like Eclipse WTP style in order to utilize
- Eclipse WTP features and to have a correct classpath. To be more precise it generates one
- project per artifact.</para>
-
- <section id="WAR">
- <title>WAR Deployment</title>
-
- <para>The project layout for WAR projects is:</para>
-
- <figure>
- <title>Project Layout for WAR projects</title>
- <mediaobject>
- <imageobject>
- <imagedata fileref="images/directory_structure/directory_structure_1.png"
- scale="75"/>
- </imageobject>
- </mediaobject>
- </figure>
-
- <para>A WAR project can only use Seam JavaBean and JPA Entity bean components; it cannot use
- EJB3 Session beans etc.</para>
- <para>WAR projects are generated to enable Seam war hotdeploy feature. Classes put
- into <emphasis>
- <property>src/action</property>
- </emphasis> will be deployed to <emphasis>
- <property>WEB-INF/dev</property>
- </emphasis> from which Seam automatically will perform hotdeploy of new
- components.</para>
- <note>
- <title>Note:</title>
- <para>Because of Eclipse WTP limits the hot deployed classes also existed in <emphasis>
- <property>WEB-INF/classes</property>, </emphasis> but since Seam gives <emphasis>
- <property>WEB-INF/dev</property>
- </emphasis> precedence it will work.</para>
- </note>
-
- <para>Furthermore the Seam Project wizard generates a test project that is setup to run
- <link linkend="testNG">TestNG</link> directly against the proper libraries and
- server runtime libraries. When the TestNG plugin is installed you can just run your
- tests via <emphasis><property>Run As > TestNG Test</property>.</emphasis></para>
- <para>In order to deploy WAR project on server, right-click on the project and select <emphasis>
- <property>Run As > Run on Server</property>.</emphasis> Studio will deploy
- WAR project into one web application on server to <property>deploy</property>
- folder.</para>
-
- </section>
-
- <section id="EAR">
- <title>EAR Deployment</title>
- <para>The project layout for EAR projects is:</para>
-
- <figure>
- <title>Project Layout for EAR projects</title>
- <mediaobject>
- <imageobject>
- <imagedata fileref="images/directory_structure/directory_structure_2.png"
- scale="75"/>
- </imageobject>
- </mediaobject>
- </figure>
-
- <para>An EAR project can use the whole range of Seam components, including EJB3 Session
- beans.</para>
- <para>In order to deploy EAR project on server, right-click on the project with
- <property>-ear</property> postfix and select <emphasis>
- <property>Run As > Run on Server</property>.</emphasis> Studio will take care
- about all modules and deploy EAR project into one enterprise application on server to
- <property>deploy</property> folder. EAR application keeps <property>ejb</property>
- and <property>war</property> modules of the EAR project.</para>
-
- <note><title>Note:</title>
- <para>The <property>WAR</property> generated for <property>EARs</property> is now configured to utilize Seam hot-deployment (<emphasis><property>WEB-INF/dev</property></emphasis>) similar to standalone <property>WAR</property> projects.</para>
-
- </note>
-
- </section>
-
- <section id="seam_version_changing">
-
- <title>Changing the Seam Version</title>
-
- <para>To upgrade or downgrade your projects Seam version use the facet preferences. You
- should right-click your project, open its <property>Properties</property> and choose <emphasis>
- <property>Project Facets</property>
- </emphasis> category. Next select <emphasis>
- <property>Seam</property>
- </emphasis> and change its version to needed one.</para>
-
- <figure>
- <title>Changing the Seam Facet Version</title>
- <mediaobject>
- <imageobject>
- <imagedata fileref="images/directory_structure/directory_structure_3.png"
- scale="75"/>
- </imageobject>
- </mediaobject>
- </figure>
-
- <para>After pressing <emphasis>
- <property>Apply</property>
- </emphasis> the wizard for adjusting new Seam runtime settings appears.</para>
-
- <figure>
- <title>Changing the Seam Facet Version</title>
- <mediaobject>
- <imageobject>
- <imagedata fileref="images/directory_structure/directory_structure_4.png"
- scale="75"/>
- </imageobject>
- </mediaobject>
- </figure>
-
- <para>If you need to update the libraries for you project, check the <emphasis>
- <property>Update libraries</property>
- </emphasis> option. All libraries you checked will be removed and the libraries from the
- new Seam distribution will be added after clicking <emphasis>
- <property>Ok</property>.</emphasis></para>
-
- <figure>
- <title>Changing the Seam Facet Version</title>
- <mediaobject>
- <imageobject>
- <imagedata fileref="images/directory_structure/directory_structure_5.png"
- scale="75"/>
- </imageobject>
- </mediaobject>
- </figure>
-
- <note>
- <title>Note:</title>
-
- <para>The note "Seam configuration files and their XSDs won't be changed" is
- meant that the libraries, Seam facet and runtime version will be changed, but
- configuration files that refer to the old version will have to be manually
- updated.</para>
- </note>
- </section>
-
- <section id="changing_seam_parent_project">
- <title>Changing Seam Parent Project</title>
-
- <para>Starting from the 2.0.0.CR2 version of <property>JBoss Tools</property> it is possible
- to change the Seam parent project. In earlier versions this was only controllable at a
- project creation time, now it can be changed for existing projects too.</para>
-
- <para>Go to your project preferences and select <emphasis>
- <property>Seam Settings</property>
- </emphasis> category on the left. Press the <emphasis>
- <property>Browse</property>
- </emphasis> button next to the <emphasis>
- <property>Main Seam Project</property>
- </emphasis> section to select the other Seam parent project.</para>
-
- <figure>
- <title>Changing Seam Parent Project</title>
- <mediaobject>
- <imageobject>
- <imagedata fileref="images/directory_structure/directory_structure_6.png"
- scale="75"/>
- </imageobject>
- </mediaobject>
- </figure>
- </section>
-
- <section id="renaming_projects_folders">
- <title>Renaming the Projects and Folders</title>
-
- <para>If you need to rename one of the Seam Project artifacts
- (<emphasis><project_name></emphasis>,
- <emphasis><project_name>-test</emphasis>,
- <emphasis><project_name>-test</emphasis> or
- <emphasis><project_name>-ejb</emphasis>) or any entire folder like
- <emphasis><project_name>/WebContent</emphasis>,
- <emphasis><project_name>/ejbModule</emphasis>,
- <emphasis><project_name>-test/test-src</emphasis>, or project name in
- packages <emphasis>org.domain.<project_name>.session</emphasis>,
- <emphasis>org.domain.<project_name>.entity</emphasis>, you can do this
- by brining the context menu and navigating <emphasis>
- <property>Refactor > Rename...</property>
- </emphasis> or just pressing <emphasis>
- <property>Shift + Alt + R</property>
- </emphasis> under the chosen resource.</para>
-
- <para>Use <emphasis>
- <property>Refactor > Move...</property>
- </emphasis> (or <emphasis>
- <property>Shift + Alt + V</property>
- </emphasis>), if you need to move
- <emphasis><project_name>/WebContent</emphasis> folder,
- <emphasis><project_name>/ejbModule</emphasis> folder or
- <emphasis><project_name>/test-src</emphasis> folder in the other place
- within the Project structure.</para>
- </section>
-</chapter>
+<?xml version="1.0" encoding="UTF-8"?>
+<chapter id="directory_str" xreflabel="directory_str">
+ <?dbhtml filename="directory_structure.html"?>
+ <chapterinfo>
+ <keywordset>
+ <keyword>JBoss Tools</keyword>
+ <keyword>Seam</keyword>
+ <keyword>Eclipse</keyword>
+ </keywordset>
+ </chapterinfo>
+
+ <title>Directory Structure of the Generated Project</title>
+
+ <para>In this chapter we describe where the Seam wizard puts the generated files for both EAR
+ and WAR deployments.</para>
+ <para>The Seam Project wizard generates projects like Eclipse WTP style in order to utilize
+ Eclipse WTP features and to have a correct classpath. To be more precise it generates one
+ project per artifact.</para>
+
+ <section id="WAR">
+ <title>WAR Deployment</title>
+
+ <para>The project layout for WAR projects is:</para>
+
+ <figure>
+ <title>Project Layout for WAR projects</title>
+ <mediaobject>
+ <imageobject>
+ <imagedata fileref="images/directory_structure/directory_structure_1.png"
+ scale="75"/>
+ </imageobject>
+ </mediaobject>
+ </figure>
+
+ <para>A WAR project can only use Seam JavaBean and JPA Entity bean components; it cannot use
+ EJB3 Session beans etc.</para>
+ <para>WAR projects are generated to enable Seam war hotdeploy feature. Classes put
+ into <emphasis>
+ <property>src/action</property>
+ </emphasis> will be deployed to <emphasis>
+ <property>WEB-INF/dev</property>
+ </emphasis> from which Seam automatically will perform hotdeploy of new
+ components.</para>
+ <note>
+ <title>Note:</title>
+ <para>Because of Eclipse WTP limits the hot deployed classes also existed in <emphasis>
+ <property>WEB-INF/classes</property>, </emphasis> but since Seam gives <emphasis>
+ <property>WEB-INF/dev</property>
+ </emphasis> precedence it will work.</para>
+ </note>
+
+ <para>Furthermore the Seam Project wizard generates a test project that is setup to run
+ <link linkend="testNG">TestNG</link> directly against the proper libraries and
+ server runtime libraries. When the TestNG plugin is installed you can just run your
+ tests via <emphasis><property>Run As > TestNG Test</property>.</emphasis></para>
+ <para>In order to deploy WAR project on server, right-click on the project and select <emphasis>
+ <property>Run As > Run on Server</property>.</emphasis> Studio will deploy
+ WAR project into one web application on server to <property>deploy</property>
+ folder.</para>
+
+ </section>
+
+ <section id="EAR">
+ <title>EAR Deployment</title>
+ <para>The project layout for EAR projects is:</para>
+
+ <figure>
+ <title>Project Layout for EAR projects</title>
+ <mediaobject>
+ <imageobject>
+ <imagedata fileref="images/directory_structure/directory_structure_2.png"
+ scale="75"/>
+ </imageobject>
+ </mediaobject>
+ </figure>
+
+ <para>An EAR project can use the whole range of Seam components, including EJB3 Session
+ beans.</para>
+ <para>In order to deploy EAR project on server, right-click on the project with
+ <property>-ear</property> postfix and select <emphasis>
+ <property>Run As > Run on Server</property>.</emphasis> Studio will take care
+ about all modules and deploy EAR project into one enterprise application on server to
+ <property>deploy</property> folder. EAR application keeps <property>ejb</property>
+ and <property>war</property> modules of the EAR project.</para>
+
+ <note><title>Note:</title>
+ <para>The <property>WAR</property> generated for <property>EARs</property> is now configured to utilize Seam hot-deployment (<emphasis><property>WEB-INF/dev</property></emphasis>) similar to standalone <property>WAR</property> projects.</para>
+
+ </note>
+
+ </section>
+
+ <section id="seam_version_changing">
+
+ <title>Changing the Seam Version</title>
+
+ <para>To upgrade or downgrade your projects Seam version use the facet preferences. You
+ should right-click your project, open its <property>Properties</property> and choose <emphasis>
+ <property>Project Facets</property>
+ </emphasis> category. Next select <emphasis>
+ <property>Seam</property>
+ </emphasis> and change its version to needed one.</para>
+
+ <figure>
+ <title>Changing the Seam Facet Version</title>
+ <mediaobject>
+ <imageobject>
+ <imagedata fileref="images/directory_structure/directory_structure_3.png"
+ scale="75"/>
+ </imageobject>
+ </mediaobject>
+ </figure>
+
+ <para>After pressing <emphasis>
+ <property>Apply</property>
+ </emphasis> the wizard for adjusting new Seam runtime settings appears.</para>
+
+ <figure>
+ <title>Changing the Seam Facet Version</title>
+ <mediaobject>
+ <imageobject>
+ <imagedata fileref="images/directory_structure/directory_structure_4.png"
+ scale="75"/>
+ </imageobject>
+ </mediaobject>
+ </figure>
+
+ <para>If you need to update the libraries for you project, check the <emphasis>
+ <property>Update libraries</property>
+ </emphasis> option. All libraries you checked will be removed and the libraries from the
+ new Seam distribution will be added after clicking <emphasis>
+ <property>Ok</property>.</emphasis></para>
+
+ <figure>
+ <title>Changing the Seam Facet Version</title>
+ <mediaobject>
+ <imageobject>
+ <imagedata fileref="images/directory_structure/directory_structure_5.png"
+ scale="75"/>
+ </imageobject>
+ </mediaobject>
+ </figure>
+
+ <note>
+ <title>Note:</title>
+
+ <para>The note "Seam configuration files and their XSDs won't be changed" is
+ meant that the libraries, Seam facet and runtime version will be changed, but
+ configuration files that refer to the old version will have to be manually
+ updated.</para>
+ </note>
+ </section>
+
+ <section id="changing_seam_parent_project">
+ <title>Changing Seam Parent Project</title>
+
+ <para>Starting from the 2.0.0.CR2 version of <property>JBoss Tools</property> it is possible
+ to change the Seam parent project. In earlier versions this was only controllable at a
+ project creation time, now it can be changed for existing projects too.</para>
+
+ <para>Go to your project preferences and select <emphasis>
+ <property>Seam Settings</property>
+ </emphasis> category on the left. Press the <emphasis>
+ <property>Browse</property>
+ </emphasis> button next to the <emphasis>
+ <property>Main Seam Project</property>
+ </emphasis> section to select the other Seam parent project.</para>
+
+ <figure>
+ <title>Changing Seam Parent Project</title>
+ <mediaobject>
+ <imageobject>
+ <imagedata fileref="images/directory_structure/directory_structure_6.png"
+ scale="75"/>
+ </imageobject>
+ </mediaobject>
+ </figure>
+ </section>
+
+ <section id="renaming_projects_folders">
+ <title>Renaming the Projects and Folders</title>
+
+ <para>If you need to rename one of the Seam Project artifacts
+ (<emphasis><project_name></emphasis>,
+ <emphasis><project_name>-ear</emphasis>,
+ <emphasis><project_name>-ejb</emphasis> or
+ <emphasis><project_name>-test</emphasis>) or any entire folder like
+ <emphasis><project_name>/WebContent</emphasis>,
+ <emphasis><project_name>/ejbModule</emphasis>,
+ <emphasis><project_name>-test/test-src</emphasis>, or project name in
+ packages <emphasis>org.domain.<project_name>.session</emphasis>,
+ <emphasis>org.domain.<project_name>.entity</emphasis>, you can do this
+ by brining the context menu and navigating <emphasis>
+ <property>Refactor > Rename...</property>
+ </emphasis> or just pressing <emphasis>
+ <property>Shift + Alt + R</property>
+ </emphasis> under the chosen resource.</para>
+
+ <figure>
+ <title>Renaming the folder</title>
+ <mediaobject>
+ <imageobject>
+ <imagedata fileref="images/directory_structure/directory_structure_7.png"
+ scale="75"/>
+ </imageobject>
+ </mediaobject>
+ </figure>
+
+ <para>Use <emphasis>
+ <property>Refactor > Move...</property>
+ </emphasis> (or <emphasis>
+ <property>Shift + Alt + V</property>
+ </emphasis>), if you need to move
+ <emphasis><project_name>/WebContent</emphasis> folder,
+ <emphasis><project_name>/ejbModule</emphasis> folder or
+ <emphasis><project_name>/test-src</emphasis> folder in the other place
+ within the Project structure.</para>
+
+ <figure>
+ <title>Moving the folder</title>
+ <mediaobject>
+ <imageobject>
+ <imagedata fileref="images/directory_structure/directory_structure_8.png"
+ scale="75"/>
+ </imageobject>
+ </mediaobject>
+ </figure>
+
+ </section>
+</chapter>
\ No newline at end of file
Added: trunk/seam/docs/reference/en-US/images/directory_structure/directory_structure_7.png
===================================================================
(Binary files differ)
Property changes on: trunk/seam/docs/reference/en-US/images/directory_structure/directory_structure_7.png
___________________________________________________________________
Name: svn:mime-type
+ application/octet-stream
Added: trunk/seam/docs/reference/en-US/images/directory_structure/directory_structure_8.png
===================================================================
(Binary files differ)
Property changes on: trunk/seam/docs/reference/en-US/images/directory_structure/directory_structure_8.png
___________________________________________________________________
Name: svn:mime-type
+ application/octet-stream
14 years, 8 months
--- trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/Annotations.java 2010-05-05 08:01:05 UTC (rev 21900)
+++ trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/Annotations.java 2010-05-05 08:11:37 UTC (rev 21901)
@@ -35,6 +35,11 @@
*/
Seam seam() default @Seam( required = false );
/**
+ * optionally require ESB runtime
+ * @return
+ */
+ ESB esb() default @ESB( required = false);
+ /**
* name of perspective to run within
* @return
*/
@@ -93,17 +98,41 @@
*/
boolean required() default true;
/**
* version of required server (use * for all)
* @return
*/
String version() default "*";
/**
* defines operator on server, possible values (=,<,>=<=,>=,!=) default =
* @return
*/
String operator() default "=";
}
+ /**
+ *
+ * @author lzoubek(a)redhat.com
+ *
+ */
+ @Retention(RetentionPolicy.RUNTIME)
+ public @interface ESB {
+ /**
+ * true if ESB is required (default)
+ * @return
+ */
+ boolean required() default true;
+ /**
+ * version of required runtime (use * for all)
+ * @return
+ */
+ String version() default "*";
+ /**
+ * defines operator on runtime version, possible values (=,<,>=<=,>=,!=) default =
+ * @return
+ */
+ String operator() default "=";
+
+ }
public enum ServerType {
/**
* EAP
@@ -93,17 +98,41 @@
boolean required() default true;
/**
- * version of required server (use * for all)
+ * version of required runtime (use * for all)
* @return
*/
@@ -93,17 +98,41 @@
String version() default "*";
/**
- * defines operator on server, possible values (=,<,>=<=,>=,!=) default =
+ * defines operator on runtime version, possible values (=,<,>=<=,>=,!=) default =
* @return
*/
Added: trunk/jst/tests/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/config/ESBBean.java
===================================================================